# coding: utf-8

"""
    syntropy-controller

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class TsoaPartialAgentObject_(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "agent_services_default_status": "bool",
        "api_key_id": "float",
        "agent_public_ipv4": "str",
        "agent_location_lat": "float",
        "agent_location_lon": "float",
        "agent_location_city": "str",
        "agent_location_country": "str",
        "agent_device_id": "str",
        "agent_name": "str",
        "agent_status": "PlatformAgentStatus",
        "agent_version": "str",
        "agent_provider_id": "float",
        "agent_is_online": "bool",
        "agent_locked_fields": "AgentLockedFields",
        "agent_modified_at": "datetime",
        "agent_is_virtual": "bool",
        "agent_type": "PlatformAgentTypeLocal",
    }

    attribute_map = {
        "agent_services_default_status": "agent_services_default_status",
        "api_key_id": "api_key_id",
        "agent_public_ipv4": "agent_public_ipv4",
        "agent_location_lat": "agent_location_lat",
        "agent_location_lon": "agent_location_lon",
        "agent_location_city": "agent_location_city",
        "agent_location_country": "agent_location_country",
        "agent_device_id": "agent_device_id",
        "agent_name": "agent_name",
        "agent_status": "agent_status",
        "agent_version": "agent_version",
        "agent_provider_id": "agent_provider_id",
        "agent_is_online": "agent_is_online",
        "agent_locked_fields": "agent_locked_fields",
        "agent_modified_at": "agent_modified_at",
        "agent_is_virtual": "agent_is_virtual",
        "agent_type": "agent_type",
    }

    def __init__(
        self,
        agent_services_default_status=None,
        api_key_id=None,
        agent_public_ipv4=None,
        agent_location_lat=None,
        agent_location_lon=None,
        agent_location_city=None,
        agent_location_country=None,
        agent_device_id=None,
        agent_name=None,
        agent_status=None,
        agent_version=None,
        agent_provider_id=None,
        agent_is_online=None,
        agent_locked_fields=None,
        agent_modified_at=None,
        agent_is_virtual=None,
        agent_type=None,
    ):  # noqa: E501
        """TsoaPartialAgentObject_ - a model defined in Swagger"""  # noqa: E501
        self._agent_services_default_status = None
        self._api_key_id = None
        self._agent_public_ipv4 = None
        self._agent_location_lat = None
        self._agent_location_lon = None
        self._agent_location_city = None
        self._agent_location_country = None
        self._agent_device_id = None
        self._agent_name = None
        self._agent_status = None
        self._agent_version = None
        self._agent_provider_id = None
        self._agent_is_online = None
        self._agent_locked_fields = None
        self._agent_modified_at = None
        self._agent_is_virtual = None
        self._agent_type = None
        self.discriminator = None
        if agent_services_default_status is not None:
            self.agent_services_default_status = agent_services_default_status
        if api_key_id is not None:
            self.api_key_id = api_key_id
        if agent_public_ipv4 is not None:
            self.agent_public_ipv4 = agent_public_ipv4
        if agent_location_lat is not None:
            self.agent_location_lat = agent_location_lat
        if agent_location_lon is not None:
            self.agent_location_lon = agent_location_lon
        if agent_location_city is not None:
            self.agent_location_city = agent_location_city
        if agent_location_country is not None:
            self.agent_location_country = agent_location_country
        if agent_device_id is not None:
            self.agent_device_id = agent_device_id
        if agent_name is not None:
            self.agent_name = agent_name
        if agent_status is not None:
            self.agent_status = agent_status
        if agent_version is not None:
            self.agent_version = agent_version
        if agent_provider_id is not None:
            self.agent_provider_id = agent_provider_id
        if agent_is_online is not None:
            self.agent_is_online = agent_is_online
        if agent_locked_fields is not None:
            self.agent_locked_fields = agent_locked_fields
        if agent_modified_at is not None:
            self.agent_modified_at = agent_modified_at
        if agent_is_virtual is not None:
            self.agent_is_virtual = agent_is_virtual
        if agent_type is not None:
            self.agent_type = agent_type

    @property
    def agent_services_default_status(self):
        """Gets the agent_services_default_status of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_services_default_status of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: bool
        """
        return self._agent_services_default_status

    @agent_services_default_status.setter
    def agent_services_default_status(self, agent_services_default_status):
        """Sets the agent_services_default_status of this TsoaPartialAgentObject_.


        :param agent_services_default_status: The agent_services_default_status of this TsoaPartialAgentObject_.  # noqa: E501
        :type: bool
        """

        self._agent_services_default_status = agent_services_default_status

    @property
    def api_key_id(self):
        """Gets the api_key_id of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The api_key_id of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: float
        """
        return self._api_key_id

    @api_key_id.setter
    def api_key_id(self, api_key_id):
        """Sets the api_key_id of this TsoaPartialAgentObject_.


        :param api_key_id: The api_key_id of this TsoaPartialAgentObject_.  # noqa: E501
        :type: float
        """

        self._api_key_id = api_key_id

    @property
    def agent_public_ipv4(self):
        """Gets the agent_public_ipv4 of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_public_ipv4 of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_public_ipv4

    @agent_public_ipv4.setter
    def agent_public_ipv4(self, agent_public_ipv4):
        """Sets the agent_public_ipv4 of this TsoaPartialAgentObject_.


        :param agent_public_ipv4: The agent_public_ipv4 of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_public_ipv4 = agent_public_ipv4

    @property
    def agent_location_lat(self):
        """Gets the agent_location_lat of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_location_lat of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_location_lat

    @agent_location_lat.setter
    def agent_location_lat(self, agent_location_lat):
        """Sets the agent_location_lat of this TsoaPartialAgentObject_.


        :param agent_location_lat: The agent_location_lat of this TsoaPartialAgentObject_.  # noqa: E501
        :type: float
        """

        self._agent_location_lat = agent_location_lat

    @property
    def agent_location_lon(self):
        """Gets the agent_location_lon of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_location_lon of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_location_lon

    @agent_location_lon.setter
    def agent_location_lon(self, agent_location_lon):
        """Sets the agent_location_lon of this TsoaPartialAgentObject_.


        :param agent_location_lon: The agent_location_lon of this TsoaPartialAgentObject_.  # noqa: E501
        :type: float
        """

        self._agent_location_lon = agent_location_lon

    @property
    def agent_location_city(self):
        """Gets the agent_location_city of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_location_city of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_location_city

    @agent_location_city.setter
    def agent_location_city(self, agent_location_city):
        """Sets the agent_location_city of this TsoaPartialAgentObject_.


        :param agent_location_city: The agent_location_city of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_location_city = agent_location_city

    @property
    def agent_location_country(self):
        """Gets the agent_location_country of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_location_country of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_location_country

    @agent_location_country.setter
    def agent_location_country(self, agent_location_country):
        """Sets the agent_location_country of this TsoaPartialAgentObject_.


        :param agent_location_country: The agent_location_country of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_location_country = agent_location_country

    @property
    def agent_device_id(self):
        """Gets the agent_device_id of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_device_id of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_device_id

    @agent_device_id.setter
    def agent_device_id(self, agent_device_id):
        """Sets the agent_device_id of this TsoaPartialAgentObject_.


        :param agent_device_id: The agent_device_id of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_device_id = agent_device_id

    @property
    def agent_name(self):
        """Gets the agent_name of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_name of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_name

    @agent_name.setter
    def agent_name(self, agent_name):
        """Sets the agent_name of this TsoaPartialAgentObject_.


        :param agent_name: The agent_name of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_name = agent_name

    @property
    def agent_status(self):
        """Gets the agent_status of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_status of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: PlatformAgentStatus
        """
        return self._agent_status

    @agent_status.setter
    def agent_status(self, agent_status):
        """Sets the agent_status of this TsoaPartialAgentObject_.


        :param agent_status: The agent_status of this TsoaPartialAgentObject_.  # noqa: E501
        :type: PlatformAgentStatus
        """

        self._agent_status = agent_status

    @property
    def agent_version(self):
        """Gets the agent_version of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_version of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: str
        """
        return self._agent_version

    @agent_version.setter
    def agent_version(self, agent_version):
        """Sets the agent_version of this TsoaPartialAgentObject_.


        :param agent_version: The agent_version of this TsoaPartialAgentObject_.  # noqa: E501
        :type: str
        """

        self._agent_version = agent_version

    @property
    def agent_provider_id(self):
        """Gets the agent_provider_id of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_provider_id of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: float
        """
        return self._agent_provider_id

    @agent_provider_id.setter
    def agent_provider_id(self, agent_provider_id):
        """Sets the agent_provider_id of this TsoaPartialAgentObject_.


        :param agent_provider_id: The agent_provider_id of this TsoaPartialAgentObject_.  # noqa: E501
        :type: float
        """

        self._agent_provider_id = agent_provider_id

    @property
    def agent_is_online(self):
        """Gets the agent_is_online of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_is_online of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: bool
        """
        return self._agent_is_online

    @agent_is_online.setter
    def agent_is_online(self, agent_is_online):
        """Sets the agent_is_online of this TsoaPartialAgentObject_.


        :param agent_is_online: The agent_is_online of this TsoaPartialAgentObject_.  # noqa: E501
        :type: bool
        """

        self._agent_is_online = agent_is_online

    @property
    def agent_locked_fields(self):
        """Gets the agent_locked_fields of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_locked_fields of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: AgentLockedFields
        """
        return self._agent_locked_fields

    @agent_locked_fields.setter
    def agent_locked_fields(self, agent_locked_fields):
        """Sets the agent_locked_fields of this TsoaPartialAgentObject_.


        :param agent_locked_fields: The agent_locked_fields of this TsoaPartialAgentObject_.  # noqa: E501
        :type: AgentLockedFields
        """

        self._agent_locked_fields = agent_locked_fields

    @property
    def agent_modified_at(self):
        """Gets the agent_modified_at of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_modified_at of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: datetime
        """
        return self._agent_modified_at

    @agent_modified_at.setter
    def agent_modified_at(self, agent_modified_at):
        """Sets the agent_modified_at of this TsoaPartialAgentObject_.


        :param agent_modified_at: The agent_modified_at of this TsoaPartialAgentObject_.  # noqa: E501
        :type: datetime
        """

        self._agent_modified_at = agent_modified_at

    @property
    def agent_is_virtual(self):
        """Gets the agent_is_virtual of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_is_virtual of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: bool
        """
        return self._agent_is_virtual

    @agent_is_virtual.setter
    def agent_is_virtual(self, agent_is_virtual):
        """Sets the agent_is_virtual of this TsoaPartialAgentObject_.


        :param agent_is_virtual: The agent_is_virtual of this TsoaPartialAgentObject_.  # noqa: E501
        :type: bool
        """

        self._agent_is_virtual = agent_is_virtual

    @property
    def agent_type(self):
        """Gets the agent_type of this TsoaPartialAgentObject_.  # noqa: E501


        :return: The agent_type of this TsoaPartialAgentObject_.  # noqa: E501
        :rtype: PlatformAgentTypeLocal
        """
        return self._agent_type

    @agent_type.setter
    def agent_type(self, agent_type):
        """Sets the agent_type of this TsoaPartialAgentObject_.


        :param agent_type: The agent_type of this TsoaPartialAgentObject_.  # noqa: E501
        :type: PlatformAgentTypeLocal
        """

        self._agent_type = agent_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(TsoaPartialAgentObject_, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TsoaPartialAgentObject_):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
